==> kubernetes-model-scheduling-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1/PriorityClassFluent.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityClassFluent<A extends PriorityClassFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public Boolean getGlobalDefault();
  public A withGlobalDefault(Boolean globalDefault);
  public Boolean hasGlobalDefault();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PriorityClassFluent.MetadataNested<A> withNewMetadata();
  public PriorityClassFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PriorityClassFluent.MetadataNested<A> editMetadata();
  public PriorityClassFluent.MetadataNested<A> editOrNewMetadata();
  public PriorityClassFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public String getPreemptionPolicy();
  public A withPreemptionPolicy(String preemptionPolicy);
  public Boolean hasPreemptionPolicy();
  public Integer getValue();
  public A withValue(Integer value);
  public Boolean hasValue();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withGlobalDefault();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PriorityClassFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}

==> kubernetes-model-scheduling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1/PriorityClassFluent.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityClassFluent<A extends PriorityClassFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public Boolean getGlobalDefault();
  public A withGlobalDefault(Boolean globalDefault);
  public Boolean hasGlobalDefault();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PriorityClassFluent.MetadataNested<A> withNewMetadata();
  public PriorityClassFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PriorityClassFluent.MetadataNested<A> editMetadata();
  public PriorityClassFluent.MetadataNested<A> editOrNewMetadata();
  public PriorityClassFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public String getPreemptionPolicy();
  public A withPreemptionPolicy(String preemptionPolicy);
  public Boolean hasPreemptionPolicy();
  public Integer getValue();
  public A withValue(Integer value);
  public Boolean hasValue();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withGlobalDefault();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PriorityClassFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}
